@@ -25,16 +25,32 @@ Tool for generating a sample configuration file. See
 
 import collections
 import copy
+import json
 import logging
 import operator
 import sys
-import textwrap
 
-import json
-import pkg_resources
+try:
+    # For oslo.config[rst-generator]
+    from docutils import core as docutils_core
+    from docutils.parsers.rst import nodes as docutils_nodes
+    from docutils.parsers.rst import roles as docutils_roles
+    import rst2txt
+    from sphinx import roles as sphinx_roles
+except ImportError:
+    import textwrap
+
+    rst2txt = None
+
+try:
+    # For Python 3.8 and later
+    import importlib.metadata as importlib_metadata
+except ImportError:
+    # For everyone else
+    import importlib_metadata
+
 import yaml
 
-
 from oslo_config import cfg
 import stevedore.named  # noqa
 
@@ -48,6 +64,7 @@ _generator_opts = [
     cfg.IntOpt(
         'wrap-width',
         default=70,
+        min=0,
         help='The maximum length of help lines.'),
     cfg.MultiStrOpt(
         'namespace',
@@ -107,15 +124,12 @@ def _format_defaults(opt):
             default_str = str(opt.sample_default)
         elif opt.default is None:
             default_str = '<None>'
-        elif (isinstance(opt, (cfg.StrOpt, cfg.IPOpt,
-                               cfg.HostnameOpt, cfg.HostAddressOpt,
-                               cfg.URIOpt))):
-            default_str = opt.default
+        elif isinstance(opt, (cfg.StrOpt, cfg.IntOpt, cfg.FloatOpt, cfg.IPOpt,
+                              cfg.PortOpt, cfg.HostnameOpt, cfg.HostAddressOpt,
+                              cfg.URIOpt, cfg.Opt)):
+            default_str = str(opt.default)
         elif isinstance(opt, cfg.BoolOpt):
             default_str = str(opt.default).lower()
-        elif isinstance(opt, (cfg.IntOpt, cfg.FloatOpt,
-                              cfg.PortOpt)):
-            default_str = str(opt.default)
         elif isinstance(opt, (cfg.ListOpt, cfg._ConfigFileOpt,
                               cfg._ConfigDirOpt)):
             default_str = ','.join(str(d) for d in opt.default)
@@ -160,7 +174,7 @@ def _format_type_name(opt_type):
     return 'unknown value'
 
 
-class _OptFormatter(object):
+class _OptFormatter:
 
     """Format configuration option descriptions to a file."""
 
@@ -171,16 +185,43 @@ class _OptFormatter(object):
         :param output_file: a writeable file object
         """
         self.output_file = output_file or sys.stdout
-        self.wrap_width = conf.wrap_width
+        self.wrap_width = conf.wrap_width or 998  # arbitrary line length
         self.minimal = conf.minimal
         self.summarize = conf.summarize
 
+        if rst2txt:
+            # register the default Sphinx roles
+            for rolename, nodeclass in sphinx_roles.generic_docroles.items():
+                generic = docutils_roles.GenericRole(rolename, nodeclass)
+                docutils_roles.register_local_role(rolename, generic)
+
+            for rolename, func in sphinx_roles.specific_docroles.items():
+                docutils_roles.register_local_role(rolename, func)
+
+            # plus our custom roles
+            for rolename in ('oslo.config:option', 'oslo.config:group'):
+                generic = docutils_roles.GenericRole(rolename,
+                                                     docutils_nodes.strong)
+                docutils_roles.register_local_role(rolename, generic)
+
     def _format_help(self, help_text):
         """Format the help for a group or option to the output file.
 
         :param help_text: The text of the help string
         """
-        if self.wrap_width is not None and self.wrap_width > 0:
+        if rst2txt:
+            help_text = docutils_core.publish_string(
+                source=help_text,
+                writer=rst2txt.Writer(),
+                settings_overrides={'wrap_width': self.wrap_width}
+            ).decode()
+
+            lines = ''
+            for line in help_text.splitlines():
+                lines += '# ' + line + '\n' if line else '#\n'
+
+            lines = [lines]
+        elif self.wrap_width > 0:
             wrapped = ""
             for line in help_text.splitlines():
                 text = "\n".join(textwrap.wrap(line, self.wrap_width,
@@ -193,6 +234,7 @@ class _OptFormatter(object):
             lines = [wrapped]
         else:
             lines = ['# ' + help_text + '\n']
+
         return lines
 
     def _get_choice_text(self, choice):
@@ -356,12 +398,12 @@ class _OptFormatter(object):
         """
         self.output_file.write(s)
 
-    def writelines(self, l):
+    def writelines(self, lines):
         """Write an arbitrary sequence of strings to the output file.
 
-        :param l: a list of arbitrary strings
+        :param lines: a list of arbitrary strings
         """
-        self.output_file.writelines(l)
+        self.output_file.writelines(lines)
 
 
 def _cleanup_opts(read_opts):
@@ -768,7 +810,7 @@ def generate(conf, output_file=None):
 
 def main(args=None):
     """The main function of oslo-config-generator."""
-    version = pkg_resources.get_distribution('oslo.config').version
+    version = importlib_metadata.version('oslo.config')
     logging.basicConfig(level=logging.WARN)
     conf = cfg.ConfigOpts()
     register_cli_opts(conf)
