@@ -15,9 +15,9 @@
 import io
 import sys
 import textwrap
+from unittest import mock
 
 import fixtures
-import mock
 from oslotest import base
 import tempfile
 import testscenarios
@@ -405,16 +405,16 @@ class GeneratorTestCase(base.BaseTestCase):
 #
 
 '''   # noqa
-'# Lorem ipsum dolor sit amet, consectetur adipisicing elit, sed do eiusmod '
-'tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam, '
-'quis nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo '
-'consequat. Duis aute irure dolor in reprehenderit in voluptate velit esse '
-'cillum dolore eu fugiat nulla pariatur. Excepteur sint occaecat cupidatat '
-'non proident, sunt in culpa qui officia deserunt mollit anim id est laborum. '
-'(string value)'
+'# Lorem ipsum dolor sit amet, consectetur adipisicing elit, sed do eiusmod '  # noqa
+'tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam, '  # noqa
+'quis nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo '  # noqa
+'consequat. Duis aute irure dolor in reprehenderit in voluptate velit esse '  # noqa
+'cillum dolore eu fugiat nulla pariatur. Excepteur sint occaecat cupidatat '  # noqa
+'non proident, sunt in culpa qui officia deserunt mollit anim id est laborum. '  # noqa
+'(string value)'  # noqa
 '''
 #long_help = <None>
-''')),
+''')),  # noqa
         ('long_help_with_preformatting',
          dict(opts=[('test', [(None, [opts['long_help_pre']])])],
               wrap_width=70,
@@ -437,7 +437,7 @@ class GeneratorTestCase(base.BaseTestCase):
 ''')),
         ('choices_opt',
          dict(opts=[('test', [(None, [opts['choices_opt']])])],
-              expected='''[DEFAULT]
+              expected="""[DEFAULT]
 
 #
 # From test
@@ -451,7 +451,7 @@ class GeneratorTestCase(base.BaseTestCase):
 # b - <No description provided>
 # c - <No description provided>
 #choices_opt = a
-''')),
+""")),
         ('deprecated opt without deprecated group',
          dict(opts=[('test',
                      [(groups['foo'],
@@ -852,13 +852,13 @@ class GeneratorTestCase(base.BaseTestCase):
 # string with bad default (string value)
 #string_type_with_bad_default = 4096
 ''')),
-         ('str_opt_str_group',
+        ('str_opt_str_group',
          dict(opts=[('test', [('foo',
                                [opts['str_opt']]),
                               (groups['foo'],
                                [opts['int_opt']])]),
                     ('foo', [('foo',
-                               [opts['bool_opt']])])],
+                              [opts['bool_opt']])])],
               expected='''[DEFAULT]
 
 
@@ -888,7 +888,7 @@ class GeneratorTestCase(base.BaseTestCase):
 # Maximum value: 20
 #int_opt = 10
 ''')),
-         ('opt_str_opt_group',
+        ('opt_str_opt_group',
          dict(opts=[('test', [(groups['foo'],
                                [opts['int_opt']]),
                               ('foo',
@@ -924,7 +924,7 @@ class GeneratorTestCase(base.BaseTestCase):
 # a string (string value)
 #str_opt = foo bar
 ''')),
-         ('opt_with_DeprecatedOpt',
+        ('opt_with_DeprecatedOpt',
          dict(opts=[('test', [(None, [opts['opt_with_DeprecatedOpt']])])],
               expected='''[DEFAULT]
 
@@ -1638,7 +1638,7 @@ class GeneratorRaiseErrorTestCase(base.BaseTestCase):
         class FakeException(Exception):
             pass
 
-        class FakeEP(object):
+        class FakeEP:
 
             def __init__(self):
                 self.name = 'callback_is_expected'
@@ -1652,8 +1652,8 @@ class GeneratorRaiseErrorTestCase(base.BaseTestCase):
         self.conf = cfg.ConfigOpts()
         self.conf.register_opts(generator._generator_opts)
         self.conf.set_default('namespace', [fake_ep.name])
-        fake_eps = mock.Mock(return_value=[fake_ep])
-        with mock.patch('pkg_resources.iter_entry_points', fake_eps):
+        with mock.patch('stevedore.named.NamedExtensionManager',
+                        side_effect=FakeException()):
             self.assertRaises(FakeException, generator.generate, self.conf)
 
     def test_generator_call_with_no_arguments_raises_system_exit(self):
